Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
Functions ¶
This section is empty.
Types ¶
type HTMLPage ¶
type HTMLPage struct {
Site state.ConfigWiki // Site settings
Page pageValues
}
HTML Template struct
type Page ¶
type Page struct {
DocumentRoot string // Document root
Path string // path to the page, including full file name
IndexPage string // The name of the default page to see when going to a namespace
Namespace string // Page Namespace
FileName string // Page file name (without the format)
ContentType string // Page Content type
Content []byte // Page contents
}
Page struct
func (*Page) ReadPage ¶
Opens a page and returns the contents as a string, or an error if there is one This will follow all pathing and filename lookup orders
func (*Page) RenderPage ¶
func (p *Page) RenderPage(w http.ResponseWriter, httpCode int) error
Render a page
Click to show internal directories.
Click to hide internal directories.